# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.10.2~6272a4a',
    built_at='2024-09-06 11:27:12Z',
    sha='6272a4a5835b9a0dee0045312e3cdfd4530c3a2a',
    branch='HEAD',
    tag='v4.10.2',
)
